@@ -69,12 +69,6 @@ test "${PY_VER}" = "${VER}"
 unset _PYTHON_SYSCONFIGDATA_NAME
 unset _CONDA_PYTHON_SYSCONFIGDATA_NAME
 
-# Remove bzip2's shared library if present,
-# as we only want to link to it statically.
-# This is important in cases where conda
-# tries to update bzip2.
-find "${PREFIX}/lib" -name "libbz2*${SHLIB_EXT}*" | xargs rm -fv {}
-
 # Prevent lib/python${VER}/_sysconfigdata_*.py from ending up with full paths to these things
 # in _build_env because _build_env will not get found during prefix replacement, only _h_env_placeh ...
 AR=$(basename "${AR}")
@@ -107,6 +101,10 @@ if [[ ${CONDA_FORGE} == yes ]]; then
   ${SYS_PYTHON} ${RECIPE_DIR}/brand_python.py
 fi
 
+if [[ "$target_platform" == linux-* ]]; then
+  cp ${PREFIX}/include/uuid/uuid.h ${PREFIX}/include/uuid.h
+fi
+
 declare -a LTO_CFLAGS=()
 
 # Following is needed for building extensions like zlib
@@ -166,6 +164,13 @@ if [[ "${CONDA_BUILD_CROSS_COMPILATION}" == "1" ]]; then
   echo "ac_cv_file__dev_ptc=yes"        >> config.site
   echo "ac_cv_pthread=yes"              >> config.site
   echo "ac_cv_little_endian_double=yes" >> config.site
+  if [[ ${target_platform} == osx-arm64 ]]; then
+      echo "ac_cv_aligned_required=no" >> config.site
+      echo "ac_cv_file__dev_ptc=no" >> config.site
+      echo "ac_cv_pthread_is_default=yes" >> config.site
+      echo "ac_cv_working_tzset=yes" >> config.site
+      echo "ac_cv_pthread_system_supported=yes" >> config.site
+  fi
   export CONFIG_SITE=${PWD}/config.site
   # This is needed for libffi:
   export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig
@@ -447,6 +452,9 @@ pushd "${PREFIX}"/lib/python${VER}
   sed -i.bak "s@$CONDA_BUILD_SYSROOT @@g" sysconfigfile
   # Remove unfilled config option
   sed -i.bak "s/@SGI_ABI@//g" sysconfigfile
+  sed -i.bak "s@$BUILD_PREFIX/bin/${HOST}-llvm-ar@${HOST}-ar@g" sysconfigfile
+  # Remove GNULD=yes to make sure new-dtags are not used
+  sed -i.bak "s/'GNULD': 'yes'/'GNULD': 'no'/g" sysconfigfile
   cp sysconfigfile ${our_compilers_name}
 
   sed -i.bak "s@${HOST}@${OLD_HOST}@g" sysconfigfile
@@ -458,7 +466,7 @@ pushd "${PREFIX}"/lib/python${VER}
   sed -i.bak "s@$OLD_HOST-@@g" sysconfigfile
   if [[ "$target_platform" == linux* ]]; then
     # For linux, make sure the system gcc uses our linker
-    sed -i.bak "s@-pthread@-pthread -B $PREFIX/compiler_compat -Wl,--sysroot=/@g" sysconfigfile
+    sed -i.bak "s@-pthread@-pthread -B $PREFIX/compiler_compat@g" sysconfigfile
   fi
   # Don't set -march and -mtune for system gcc
   sed -i.bak "s@-march=[a-z0-9]*@@g" sysconfigfile
@@ -474,6 +482,9 @@ pushd "${PREFIX}"/lib/python${VER}
   # Cleanup some extra spaces from above
   sed -i.bak "s@' [ ]*@'@g" sysconfigfile
   cp sysconfigfile $recorded_name
+  echo "========================sysconfig==========================="
+  cat $recorded_name
+  echo "============================================================"
 
   rm sysconfigfile
   rm sysconfigfile.bak
@@ -491,3 +502,6 @@ rm -rf ${PREFIX}/lib/python${VER}/distutils/command/*.exe
 
 python -c "import compileall,os;compileall.compile_dir(os.environ['PREFIX'])"
 rm ${PREFIX}/lib/libpython${VER}.a
+if [[ "$target_platform" == linux-* ]]; then
+  rm ${PREFIX}/include/uuid.h
+fi
